.. _john-nash-reference:

John Nash
=========

.. <!--alex disable he-she-->
.. <!--alex disable her-him-->

This library is named after the mathematician John Nash. He is most famous for
his work in Game Theory that culminated in him winning a Noble prize in
Economics. The book [Nasar2011]_ (popularized in a 2001 movie) gives a good
overview of his life.

The work he received a Noble prize for was a proof that a game **always** has
an equilibrium [Nash1950]_. His proof is an exceptional piece of mathematics
where he uses a fixed point theorem by showing that an equilibrium is equivalent
to a fixed point of a function.

..  <!--alex enable he-she-->
..  <!--alex enable her-him-->

Subsequently, these equilibria have been referred to as Nash equilibria.
